==> openshift-model-6.8.1-sources.jar: io/fabric8/openshift/api/model/SourceStrategyOptionsFluent.java <==
package io.fabric8.openshift.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SourceStrategyOptionsFluent<A extends SourceStrategyOptionsFluent<A>> extends BaseFluent<A>{
  public SourceStrategyOptionsFluent() {
  }
  public SourceStrategyOptionsFluent(SourceStrategyOptions instance) {
    instance = (instance != null ? instance : new SourceStrategyOptions());

    if (instance != null) {
      this.withIncremental(instance.getIncremental());
      this.withIncremental(instance.getIncremental());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private Boolean incremental;
  private Map<String,Object> additionalProperties;
  public Boolean getIncremental() {
    return this.incremental;
  }
  public A withIncremental(Boolean incremental) {
    this.incremental=incremental; return (A) this;
  }
  public boolean hasIncremental() {
    return this.incremental != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SourceStrategyOptionsFluent that = (SourceStrategyOptionsFluent) o;
    if (!java.util.Objects.equals(incremental, that.incremental)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(incremental,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (incremental != null) { sb.append("incremental:"); sb.append(incremental + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public A withIncremental() {
    return withIncremental(true);
  }
  
}

==> openshift-model-6.9.0-sources.jar: io/fabric8/openshift/api/model/SourceStrategyOptionsFluent.java <==
package io.fabric8.openshift.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class SourceStrategyOptionsFluent<A extends SourceStrategyOptionsFluent<A>> extends BaseFluent<A>{
  public SourceStrategyOptionsFluent() {
  }
  
  public SourceStrategyOptionsFluent(SourceStrategyOptions instance) {
    this.copyInstance(instance);
  }
  private Boolean incremental;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(SourceStrategyOptions instance) {
    instance = (instance != null ? instance : new SourceStrategyOptions());
  
    if (instance != null) {
        this.withIncremental(instance.getIncremental());
        this.withIncremental(instance.getIncremental());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public Boolean getIncremental() {
    return this.incremental;
  }
  
  public A withIncremental(Boolean incremental) {
    this.incremental=incremental; return (A) this;
  }
  
  public boolean hasIncremental() {
    return this.incremental != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SourceStrategyOptionsFluent that = (SourceStrategyOptionsFluent) o;
    if (!java.util.Objects.equals(incremental, that.incremental)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(incremental,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (incremental != null) { sb.append("incremental:"); sb.append(incremental + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
  public A withIncremental() {
    return withIncremental(true);
  }
  

}
